Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(4568)

Unified Diff: content/public/android/java/src/org/chromium/content/browser/WebContentsObserverAndroid.java

Issue 304763002: Trust the renderer's same-document navigation flag if it is a same-origin nav. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: isNavigationInPage->isFragmentNavigation, with caveat on the name Created 6 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/public/android/java/src/org/chromium/content/browser/WebContentsObserverAndroid.java
diff --git a/content/public/android/java/src/org/chromium/content/browser/WebContentsObserverAndroid.java b/content/public/android/java/src/org/chromium/content/browser/WebContentsObserverAndroid.java
index 17081e505a66d1b7e8fcb90d356e9ba7cd9c86e5..66e84ad20ceecc8759c93133619a77f29266bed7 100644
--- a/content/public/android/java/src/org/chromium/content/browser/WebContentsObserverAndroid.java
+++ b/content/public/android/java/src/org/chromium/content/browser/WebContentsObserverAndroid.java
@@ -55,12 +55,12 @@ public abstract class WebContentsObserverAndroid {
* @param url The validated url for the page.
* @param baseUrl The validated base url for the page.
* @param isNavigationToDifferentPage Whether the main frame navigated to a different page.
* @param isNavigationInPage Whether the main frame navigation did not cause changes to the
* document (for example scrolling to a named anchor or PopState).
*/
@CalledByNative
public void didNavigateMainFrame(String url, String baseUrl,
- boolean isNavigationToDifferentPage, boolean isNavigationInPage) {
+ boolean isNavigationToDifferentPage, boolean isFragmentNavigation) {
}
/**
@@ -55,12 +55,12 @@ public abstract class WebContentsObserverAndroid {
* @param baseUrl The validated base url for the page.
* @param isNavigationToDifferentPage Whether the main frame navigated to a different page.
- * @param isNavigationInPage Whether the main frame navigation did not cause changes to the
- * document (for example scrolling to a named anchor or PopState).
+ * @param isFragmentNavigation Whether the main frame navigation did not cause changes to the
+ * document (for example scrolling to a named anchor or PopState).
*/

Powered by Google App Engine
This is Rietveld 408576698